.. _lAJ2lonrTE:

=======================================
Bunkers
=======================================

**Lost city on underground World War Two bunkers built by Nazis FOUND on Dutch coast**

- https://www.express.co.uk/news/world/805894/World-War-Two-bunkers-lost-city-underground-Nazis-Dutch-coast



**Switzerland’s Historic Bunkers Get a New Lease on Life**

- https://www.smithsonianmag.com/travel/switzerlands-bunkers-get-new-lease-life-180958233/



**The forgotten underground world of Swiss bunkers**

https://www.swissinfo.ch/eng/society/in-case-of-emergency_the-forgotten-underground-world-of-swiss-bunkers/42395820

